"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.checkValidity = exports.replaceInArray = exports.changeShow = exports.getElementByName = exports.formElementHelper = void 0;

function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i] != null ? arguments[i] : {};
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(
                Object.getOwnPropertySymbols(source).filter(function(sym) {
                    return Object.getOwnPropertyDescriptor(source, sym).enumerable;
                })
            );
        }
        ownKeys.forEach(function(key) {
            _defineProperty(target, key, source[key]);
        });
    }
    return target;
}

function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}

function _objectWithoutProperties(source, excluded) {
    if (source == null) return {};
    var target = {};
    var sourceKeys = Object.keys(source);
    var key, i;
    for (i = 0; i < sourceKeys.length; i++) {
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0) continue;
        target[key] = source[key];
    }
    if (Object.getOwnPropertySymbols) {
        var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
        for (i = 0; i < sourceSymbolKeys.length; i++) {
            key = sourceSymbolKeys[i];
            if (excluded.indexOf(key) >= 0) continue;
            if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
            target[key] = source[key];
        }
    }
    return target;
}

var formElementHelper = function formElementHelper(_ref) {
    var formType = _ref.formType,
        _ref$validation = _ref.validation,
        validation = _ref$validation === void 0 ? {} : _ref$validation,
        _ref$value = _ref.value,
        value = _ref$value === void 0 ? "" : _ref$value,
        _ref$show = _ref.show,
        show = _ref$show === void 0 ? true : _ref$show,
        other = _objectWithoutProperties(_ref, ["formType", "validation", "value", "show"]);

    return _objectSpread(
        {
            formType: formType,
            value: value,
            validation: validation,
            valid: false,
            touched: false,
            show: show
        },
        other
    );
};

exports.formElementHelper = formElementHelper;

var getElementByName = function getElementByName(array, elName) {
    return array.find(function(el) {
        return el.name === elName;
    });
};

exports.getElementByName = getElementByName;

var changeShow = function changeShow(array, whatToShow, show) {
    if (typeof whatToShow === "string") whatToShow = [whatToShow];
    return array.map(function(item) {
        if (whatToShow.includes(item.name)) {
            return _objectSpread(
                {},
                array.find(function(item) {
                    return (
                        item.name ===
                        whatToShow.find(function(arrayItem) {
                            return item.name === arrayItem;
                        })
                    );
                }),
                {
                    show: show
                }
            );
        }

        return item;
    });
};

exports.changeShow = changeShow;

var replaceInArray = function replaceInArray(array, name, newValues) {
    return array.map(function(item) {
        if (item.name === name) {
            return _objectSpread(
                {},
                array.find(function(item) {
                    return item.name === name;
                }),
                newValues
            );
        }

        return item;
    });
};

exports.replaceInArray = replaceInArray;

var checkValidity = function checkValidity(value, rules) {
    var isValid = true;

    if (!rules) {
        return true;
    }

    if (rules.required) {
        isValid = (typeof value === "string" ? value.trim() !== "" : !!value) && isValid;
    }

    if (rules.minLength) {
        isValid = value.length >= rules.minLength && isValid;
    }

    if (rules.maxLength) {
        isValid = value.length <= rules.maxLength && isValid;
    }

    if (rules.isEmail) {
        var pattern = /[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?/;
        isValid = pattern.test(value) && isValid;
    }

    if (rules.isNumeric) {
        var _pattern = /^\d+$/;
        isValid = _pattern.test(value) && isValid;
    }

    return isValid;
};

exports.checkValidity = checkValidity;
